<?php

namespace Kscc\Organization\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Kscc\Organization\Interfaces\OrganizationRepositoryInterface;

class OrganizationPublicController extends BaseController
{
    // use OrganizationWorkflow;

    /**
     * Constructor.
     *
     * @param type \Kscc\Organization\Interfaces\OrganizationRepositoryInterface $organization
     *
     * @return type
     */
    public function __construct(OrganizationRepositoryInterface $organization)
    {
        $this->repository = $organization;
        parent::__construct();
    }

    /**
     * Show organization's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $organizations = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('organization::organization.names'))
            ->view('organization::public.organization.index')
            ->data(compact('organizations'))
            ->output();
    }


    /**
     * Show organization.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $organization = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($organization->name . trans('organization::organization.name'))
            ->view('organization::public.organization.show')
            ->data(compact('organization'))
            ->output();
    }

}
