<?php

namespace Kscc\Organization\Policies;

use Litepie\User\Contracts\UserPolicy;
use Kscc\Organization\Models\Organization;

class OrganizationPolicy
{

    /**
     * Determine if the given user can view the organization.
     *
     * @param UserPolicy $user
     * @param Organization $organization
     *
     * @return bool
     */
    public function view(UserPolicy $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.view') && $user->isAdmin()) {
            return true;
        }

        return $organization->user_id == user_id() && $organization->user_type == user_type();
    }

    /**
     * Determine if the given user can create a organization.
     *
     * @param UserPolicy $user
     * @param Organization $organization
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('organization.organization.create');
    }

    /**
     * Determine if the given user can update the given organization.
     *
     * @param UserPolicy $user
     * @param Organization $organization
     *
     * @return bool
     */
    public function update(UserPolicy $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.edit') && $user->isAdmin()) {
            return true;
        }

        return $organization->user_id == user_id() && $organization->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given organization.
     *
     * @param UserPolicy $user
     * @param Organization $organization
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Organization $organization)
    {
        return $organization->user_id == user_id() && $organization->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given organization.
     *
     * @param UserPolicy $user
     * @param Organization $organization
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given organization.
     *
     * @param UserPolicy $user
     * @param Organization $organization
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
